@@ -10,22 +10,25 @@ def get_index(a, b):
         b (list): List for searching.
 
     Returns:
-        inx (list or int): The index of the given elements in the list.
+        inx (list or int): The index of the given elements in the list b.
+        inx_converse (list or int): The index of the given elements in the list a.
     """
 
     inx = []
-
+    inx_converse = []
     # Check the type of the given element, whether it is a single one or several items.
     if isinstance(a, list) | isinstance(a, np.ndarray):
         for x in a:
             try:
                 inx.append(b.index(x))
-            except:
+                inx_converse.append(a.index(x))
+            except ValueError:
                 pass
     else:
         try:
             inx.append(b.index(a))
-        except:
+            inx_converse.append(a.index(a))
+        except ValueError:
             pass
 
-    return inx
\ No newline at end of file
+    return inx, inx_converse
\ No newline at end of file
